@@ -9,10 +9,10 @@ def copy_both_assets():
     create_helper.copy_assets_to_machine(which="settings")
 
 
-def update(no_copy_assets: Annotated[bool, typer.Option("--no-assets-copy", "-na", help="Copy (overwrite) assets to the machine after the update")] = False):
+def update(copy_assets: Annotated[bool, typer.Option("--assets-copy/--no-assets-copy", "-a/-na", help="Copy (overwrite) assets to the machine after the update")] = True,
+           link_public_configs: Annotated[bool, typer.Option("--link-public-configs/--no-link-public-configs", "-b/-nb", help="Link public configs after update (overwrites your configs!)")] = False,
+           ):
     """🔄 UPDATE uv and machineconfig"""
-    # from machineconfig.utils.source_of_truth import LIBRARY_ROOT
-    # repo_root = LIBRARY_ROOT.parent.parent
     from pathlib import Path
     if Path.home().joinpath("code", "machineconfig").exists():
         shell_script = """
@@ -30,14 +30,19 @@ uv tool install --upgrade machineconfig
     if platform.system() == "Windows":
         from machineconfig.utils.code import exit_then_run_shell_script, get_uv_command_executing_python_script
         from machineconfig.utils.meta import lambda_to_python_script
-        python_script = lambda_to_python_script(lambda: copy_both_assets(), in_global=True, import_module=False)
+        python_script = lambda_to_python_script(lambda: copy_both_assets(),
+                                                in_global=True, import_module=False)
         uv_command, _py_file = get_uv_command_executing_python_script(python_script=python_script, uv_with=["machineconfig"], uv_project_dir=None)
         exit_then_run_shell_script(shell_script + "\n" + uv_command, strict=True)
     else:
         from machineconfig.utils.code import run_shell_script
         run_shell_script(shell_script)
-    if not no_copy_assets:
-        copy_both_assets()
+        if copy_assets:
+            copy_both_assets()
+        if link_public_configs:
+            import machineconfig.profile.create_links_export as create_links_export
+            create_links_export.main_public_from_parser(method="copy", on_conflict="overwrite-default-path", which="all", interactive=False)
+
 
 def install(no_copy_assets: Annotated[bool, typer.Option("--no-assets-copy", "-na", help="Copy (overwrite) assets to the machine after the update")] = False):
     """📋 CLONE machienconfig locally and incorporate to shell profile for faster execution and nightly updates."""
@@ -48,9 +53,9 @@ def install(no_copy_assets: Annotated[bool, typer.Option("--no-assets-copy", "-n
     else:
         import platform
         if platform.system() == "Windows":
-            run_shell_script(r"""& "$HOME\.local\bin\uv.exe" tool install --upgrade "machineconfig>=7.36" """)
+            run_shell_script(r"""& "$HOME\.local\bin\uv.exe" tool install --upgrade "machineconfig>=7.68" """)
         else:
-            run_shell_script("""$HOME/.local/bin/uv tool install --upgrade "machineconfig>=7.36" """)
+            run_shell_script("""$HOME/.local/bin/uv tool install --upgrade "machineconfig>=7.68" """)
     from machineconfig.profile.create_shell_profile import create_default_shell_profile
     if not no_copy_assets:
         create_default_shell_profile()   # involves copying assets too
@@ -73,10 +78,10 @@ def navigate():
     import machineconfig.scripts.python as navigator
     from pathlib import Path
     path = Path(navigator.__file__).resolve().parent.joinpath("devops_navigator.py")
-    from machineconfig.utils.code import run_shell_script
+    from machineconfig.utils.code import exit_then_run_shell_script
     if Path.home().joinpath("code/machineconfig").exists(): executable = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" --with textual"""
-    else: executable = """--with "machineconfig>=7.36,textual" """
-    run_shell_script(f"""uv run {executable} {path}""")
+    else: executable = """--with "machineconfig>=7.68,textual" """
+    exit_then_run_shell_script(f"""uv run {executable} {path}""")
 
 
 def run_python(ip: Annotated[str, typer.Argument(..., help="Python command to run in the machineconfig environment")],
