@@ -1,28 +1,47 @@
-import git
-from rich.console import Console
-from rich.panel import Panel
-import typer
 
-from machineconfig.utils.path_extended import PathExtended
-from machineconfig.utils.terminal import Response
-from machineconfig.utils.source_of_truth import CONFIG_ROOT, DEFAULTS_PATH
-from machineconfig.utils.code import get_uv_command_executing_python_script
-from pathlib import Path
-import platform
-import subprocess
 from typing import Optional, Literal, Annotated
 
-
-console = Console()
+import typer
 
 
 def main(
     cloud: Annotated[Optional[str], typer.Option(..., "--cloud", "-c", help="Cloud storage profile name. If not provided, uses default from config.")] = None,
     repo: Annotated[Optional[str], typer.Option(..., "--repo", "-r", help="Path to the local repository. Defaults to current working directory.")] = None,
     message: Annotated[Optional[str], typer.Option(..., "--message", "-m", help="Commit message for local changes.")] = None,
-    on_conflict: Annotated[Literal["ask", "push-local-merge", "overwrite-local", "stop-on-conflict", "remove-rclone-conflict"], typer.Option(..., "--on-conflict", "-oc", help="Action to take on merge conflict. Default is 'ask'.")] = "ask",
+    on_conflict: Annotated[Literal["ask", "a",
+                                   "push-local-merge", "p",
+                                   "overwrite-local", "o",
+                                   "stop-on-conflict", "s",
+                                   "remove-rclone-conflict", "r"
+                                   ], typer.Option(..., "--on-conflict", "-o", help="Action to take on merge conflict. Default is 'ask'.")] = "ask",
     pwd: Annotated[Optional[str], typer.Option(..., "--password", help="Password for encryption/decryption of the remote repository.")] = None,
 ):
+    on_conflict_mapper: dict[str, Literal["ask", "push-local-merge", "overwrite-local", "stop-on-conflict", "remove-rclone-conflict"]] = {
+        "a": "ask",
+        "ask": "ask",
+        "p": "push-local-merge",
+        "push-local-merge": "push-local-merge",
+        "o": "overwrite-local",
+        "overwrite-local": "overwrite-local",
+        "s": "stop-on-conflict",
+        "stop-on-conflict": "stop-on-conflict",
+        "r": "remove-rclone-conflict",
+        "remove-rclone-conflict": "remove-rclone-conflict",
+    }
+    on_conflict = on_conflict_mapper[on_conflict]
+    import git
+    from rich.console import Console
+    from rich.panel import Panel
+
+    from machineconfig.utils.path_extended import PathExtended
+    from machineconfig.utils.terminal import Response
+    from machineconfig.utils.source_of_truth import CONFIG_ROOT, DEFAULTS_PATH
+    from machineconfig.utils.code import get_uv_command_executing_python_script
+    from pathlib import Path
+    import platform
+    import subprocess
+    console = Console()
+
     if cloud is None:
         try:
             from machineconfig.utils.io import read_ini
@@ -35,10 +54,16 @@ def main(
     else:
         cloud_resolved = cloud
     repo_local_root = PathExtended.cwd() if repo is None else PathExtended(repo).expanduser().absolute()
-    repo_local_obj = git.Repo(repo_local_root, search_parent_directories=True)
+    try:
+        repo_local_obj = git.Repo(repo_local_root, search_parent_directories=True)
+    except git.InvalidGitRepositoryError:
+        typer.echo(f"[red]Error:[/] The specified path '{repo_local_root}' is not a valid git repository.")
+        typer.Exit(code=1)
+        return ""
     repo_local_root = PathExtended(repo_local_obj.working_dir)  # cwd might have been in a sub directory of repo_root, so its better to redefine it.
+    local_relative_home = PathExtended(repo_local_root.expanduser().absolute().relative_to(Path.home()))
     PathExtended(CONFIG_ROOT).joinpath("remote").mkdir(parents=True, exist_ok=True)
-    repo_remote_root = PathExtended(CONFIG_ROOT).joinpath("remote", repo_local_root.rel2home())
+    repo_remote_root = PathExtended(CONFIG_ROOT).joinpath("remote", local_relative_home)
     repo_remote_root.delete(sure=True)
     try:
         console.print(Panel("📥 DOWNLOADING REMOTE REPOSITORY", title_align="left", border_style="blue"))
@@ -80,7 +105,7 @@ git pull originEnc master
         uv_project_dir = f"""{str(Path.home().joinpath("code/machineconfig"))}"""
         uv_with = None
     else:
-        uv_with = ["machineconfig>=7.36"]
+        uv_with = ["machineconfig>=7.68"]
         uv_project_dir = None
 
     import tempfile
@@ -111,7 +136,8 @@ git pull originEnc master
         def func2(remote_repo: str, local_repo: str, cloud: str):
             from machineconfig.scripts.python.helpers_repos.sync import delete_remote_repo_copy_and_push_local
             delete_remote_repo_copy_and_push_local(remote_repo=remote_repo, local_repo=local_repo, cloud=cloud)
-        program_1_py = lambda_to_python_script(lambda: func2(remote_repo=str(repo_remote_root), local_repo=str(repo_local_root), cloud=str(cloud_resolved)), in_global=True, import_module=False)
+        program_1_py = lambda_to_python_script(lambda: func2(remote_repo=str(repo_remote_root), local_repo=str(repo_local_root), cloud=str(cloud_resolved)),
+in_global=True, import_module=False)
         program1, _pyfile1 = get_uv_command_executing_python_script(python_script=program_1_py, uv_with=uv_with, uv_project_dir=uv_project_dir)
         # ================================================================================
         option2 = "Delete local repo and replace it with remote copy:"
@@ -136,7 +162,8 @@ sudo chmod +x $HOME/dotfiles/scripts/linux -R
             inspect_repos(repo_local_root=repo_local_root, repo_remote_root=repo_remote_root)
         # program_3_py = function_to_script(func=func, call_with_kwargs={"repo_local_root": str(repo_local_root), "repo_remote_root": str(repo_remote_root)})
         # shell_file_3 = get_shell_file_executing_python_script(python_script=program_3_py, ve_path=None, executable=executable)
-        program_3_py = lambda_to_python_script(lambda: func(repo_local_root=str(repo_local_root), repo_remote_root=str(repo_remote_root)), in_global=True, import_module=False)
+        program_3_py = lambda_to_python_script(lambda: func(repo_local_root=str(repo_local_root), repo_remote_root=str(repo_remote_root)),
+in_global=True, import_module=False)
         program3, _pyfile3 = get_uv_command_executing_python_script(python_script=program_3_py, uv_with=uv_with, uv_project_dir=uv_project_dir)
         # ================================================================================
 
